@@ -9,6 +9,9 @@
 
 
 
+
+
+
 rootogram0 <- function(object, ...) {
   UseMethod("rootogram0")
 }
@@ -19,6 +22,7 @@ rootogram0 <- function(object, ...) {
 
 
 
+
 rootogram0.default <-
   function(object, fitted, breaks = NULL,
            style = c("hanging", "standing", "suspended"),
@@ -28,8 +32,8 @@ rootogram0.default <-
 
 
   ## rectangle style
-  scale <- match.arg(scale)
-  style <- match.arg(style)
+  scale <- match.arg(scale, c("sqrt", "raw"))[1]
+  style <- match.arg(style, c("hanging", "standing", "suspended"))[1]
 
   ## default annotation
   if (is.null(xlab)) {
@@ -160,3 +164,8 @@ plot.rootogram0 <- function(x,
 
 
 
+
+
+
+
+
