@@ -1,4 +1,4 @@
-C Output from Public domain Ratfor, version 1.01
+C Output from Public domain Ratfor, version 1.04
       subroutine vbvs(kuzxj1lo,ankcghz2,rpyis2kc,nk,he7mqnvy,smat,order,
      *wy1vqfzu)
       integer kuzxj1lo, nk, order, wy1vqfzu
@@ -13,9 +13,9 @@ C Output from Public domain Ratfor, version 1.01
       call wbvalue(ankcghz2, rpyis2kc(1,yq6lorbx), nk, ifour4, chw8lzty,
      * order, smat(ayfnwr1v,yq6lorbx))
 23002 continue
-C23003 continue
+23003 continue
 23000 continue
-C23001 continue
+23001 continue
       return
       end
       subroutine tfeswo7c(osiz4fxy, nk, wy1vqfzu, ldk, wbkq9zyi, sgmat)
@@ -29,36 +29,36 @@ C23001 continue
       osiz4fxy(ldk,(ayfnwr1v-1)*wy1vqfzu+yq6lorbx) = osiz4fxy(ldk,(ayfnw
      *r1v-1)*wy1vqfzu+yq6lorbx) + wbkq9zyi(yq6lorbx) * sgmat(ayfnwr1v,1)
 23006 continue
-C23007 continue
+23007 continue
 23004 continue
-C23005 continue
+23005 continue
       do23008 ayfnwr1v=1,(nk-1) 
       do23010 yq6lorbx=1,wy1vqfzu 
       osiz4fxy(ldk-wy1vqfzu,(ayfnwr1v-0)*wy1vqfzu+yq6lorbx) = osiz4fxy(l
      *dk-wy1vqfzu,(ayfnwr1v-0)*wy1vqfzu+yq6lorbx) + wbkq9zyi(yq6lorbx) *
      * sgmat(ayfnwr1v,2)
 23010 continue
-C23011 continue
+23011 continue
 23008 continue
-C23009 continue
+23009 continue
       do23012 ayfnwr1v=1,(nk-2) 
       do23014 yq6lorbx=1,wy1vqfzu 
       osiz4fxy(ldk-2*wy1vqfzu,(ayfnwr1v+1)*wy1vqfzu+yq6lorbx) = osiz4fxy
      *(ldk-2*wy1vqfzu,(ayfnwr1v+1)*wy1vqfzu+yq6lorbx) + wbkq9zyi(yq6lorb
      *x) * sgmat(ayfnwr1v,3)
 23014 continue
-C23015 continue
+23015 continue
 23012 continue
-C23013 continue
+23013 continue
       do23016 ayfnwr1v=1,(nk-3) 
       do23018 yq6lorbx=1,wy1vqfzu 
       osiz4fxy(ldk-3*wy1vqfzu,(ayfnwr1v+2)*wy1vqfzu+yq6lorbx) = osiz4fxy
      *(ldk-3*wy1vqfzu,(ayfnwr1v+2)*wy1vqfzu+yq6lorbx) + wbkq9zyi(yq6lorb
      *x) * sgmat(ayfnwr1v,4)
 23018 continue
-C23019 continue
+23019 continue
 23016 continue
-C23017 continue
+23017 continue
       return
       end
       subroutine ybnagt8k(iii, cz8qdfyj, tesdm5kv, g9fvdrbw, osiz4fxy, w
@@ -90,7 +90,7 @@ C23017 continue
      *tcex
       endif
 23020 continue
-C23021 continue
+23021 continue
       return
       end
       subroutine vsplin(he7mqnvy,rbne6ouj,wmat,kuzxj1lo,gkdx5jal, nk,ldk
@@ -152,7 +152,7 @@ C23021 continue
       rbne6ouj(ayfnwr1v,yq6lorbx) = rbne6ouj(ayfnwr1v,yq6lorbx) / wmat(a
      *yfnwr1v,yq6lorbx)
 23038 continue
-C23039 continue
+23039 continue
       call dnaoqj0l(penalt, dof(yq6lorbx), he7mqnvy, rbne6ouj(1,yq6lorbx
      *), wmat(1,yq6lorbx), kuzxj1lo,nk, gkdx5jal,rpyis2kc(1,yq6lorbx), t
      *8hwvalr(1,yq6lorbx), ifys6woa(1,yq6lorbx), qcpiaj7f,wbkq9zyi(yq6lo
@@ -164,13 +164,13 @@ C23039 continue
       wmat(ayfnwr1v,yq6lorbx) = wmat(ayfnwr1v,yq6lorbx) * wmat(ayfnwr1v,
      *yq6lorbx)
 23042 continue
-C23043 continue
+23043 continue
       if(yzoe1rsp .ne. 0)then
       do23046 ayfnwr1v=1,kuzxj1lo 
       ui8ysltq(ayfnwr1v,yq6lorbx) = ifys6woa(ayfnwr1v,yq6lorbx) / wmat(a
      *yfnwr1v,yq6lorbx)
 23046 continue
-C23047 continue
+23047 continue
       endif
       else
       call dnaoqj0l(penalt, dof(yq6lorbx), he7mqnvy, btwy(1,yq6lorbx), w
@@ -184,14 +184,14 @@ C23047 continue
       wmat(ayfnwr1v,yq6lorbx) = wmat(ayfnwr1v,yq6lorbx) * wmat(ayfnwr1v,
      *yq6lorbx)
 23050 continue
-C23051 continue
+23051 continue
       endif
       if(fbd5yktj .ne. 0)then
       return
       endif
       endif
 23024 continue
-C23025 continue
+23025 continue
       if((wy1vqfzu .eq. 1) .or. (dimw .eq. wy1vqfzu))then
       return
       endif
@@ -199,16 +199,16 @@ C23025 continue
       do23058 yq6lorbx=1,wy1vqfzu 
       btwy(yq6lorbx,ayfnwr1v)=0.0d0
 23058 continue
-C23059 continue
+23059 continue
 23056 continue
-C23057 continue
+23057 continue
       do23060 ayfnwr1v=1,(nk*wy1vqfzu) 
       do23062 yq6lorbx=1,ldk 
       osiz4fxy(yq6lorbx,ayfnwr1v) = 0.0d0
 23062 continue
-C23063 continue
+23063 continue
 23060 continue
-C23061 continue
+23061 continue
       qaltf0nz = 0.1d-9
       do23064 ayfnwr1v=1,kuzxj1lo 
       call vinterv(gkdx5jal(1),(nk+1),he7mqnvy(ayfnwr1v),dqlr5bse,pqzfxw
@@ -227,7 +227,7 @@ C23061 continue
       btwy(urohxe6t,yq6lorbx)=btwy(urohxe6t,yq6lorbx) + rbne6ouj(ayfnwr1
      *v,urohxe6t) * g9fvdrbw(1,1)
 23070 continue
-C23071 continue
+23071 continue
       call ybnagt8k(ayfnwr1v, yq6lorbx, 0, g9fvdrbw, osiz4fxy, wmat, 1, 
      *1, wy1vqfzu, ldk, dimw, kuzxj1lo, nk, tgiyxdw1, dufozmt7)
       call ybnagt8k(ayfnwr1v, yq6lorbx, 1, g9fvdrbw, osiz4fxy, wmat, 1, 
@@ -241,7 +241,7 @@ C23071 continue
       btwy(urohxe6t,yq6lorbx)=btwy(urohxe6t,yq6lorbx) + rbne6ouj(ayfnwr1
      *v,urohxe6t) * g9fvdrbw(2,1)
 23072 continue
-C23073 continue
+23073 continue
       call ybnagt8k(ayfnwr1v, yq6lorbx, 0, g9fvdrbw, osiz4fxy, wmat, 2, 
      *2, wy1vqfzu, ldk, dimw, kuzxj1lo, nk, tgiyxdw1, dufozmt7)
       call ybnagt8k(ayfnwr1v, yq6lorbx, 1, g9fvdrbw, osiz4fxy, wmat, 2, 
@@ -253,7 +253,7 @@ C23073 continue
       btwy(urohxe6t,yq6lorbx)=btwy(urohxe6t,yq6lorbx) + rbne6ouj(ayfnwr1
      *v,urohxe6t) * g9fvdrbw(3,1)
 23074 continue
-C23075 continue
+23075 continue
       call ybnagt8k(ayfnwr1v, yq6lorbx, 0, g9fvdrbw, osiz4fxy, wmat, 3, 
      *3, wy1vqfzu, ldk, dimw, kuzxj1lo, nk, tgiyxdw1, dufozmt7)
       call ybnagt8k(ayfnwr1v, yq6lorbx, 1, g9fvdrbw, osiz4fxy, wmat, 3, 
@@ -263,11 +263,11 @@ C23075 continue
       btwy(urohxe6t,yq6lorbx)=btwy(urohxe6t,yq6lorbx) + rbne6ouj(ayfnwr1
      *v,urohxe6t) * g9fvdrbw(4,1)
 23076 continue
-C23077 continue
+23077 continue
       call ybnagt8k(ayfnwr1v, yq6lorbx, 0, g9fvdrbw, osiz4fxy, wmat, 4, 
      *4, wy1vqfzu, ldk, dimw, kuzxj1lo, nk, tgiyxdw1, dufozmt7)
 23064 continue
-C23065 continue
+23065 continue
       call zosq7hub(sgdub(1,1), sgdub(1,2), sgdub(1,3), sgdub(1,4), gkdx
      *5jal, nk)
       call tfeswo7c(osiz4fxy, nk, wy1vqfzu, ldk, wbkq9zyi, sgdub)
@@ -282,9 +282,9 @@ C23065 continue
       i1loc = i1loc + 1
       rpyis2kc(ayfnwr1v,yq6lorbx) = btwy(yq6lorbx,ayfnwr1v)
 23082 continue
-C23083 continue
+23083 continue
 23080 continue
-C23081 continue
+23081 continue
       call cn8kzpab(gkdx5jal, he7mqnvy, rpyis2kc, kuzxj1lo, nk, wy1vqfzu
      *, t8hwvalr)
       call vicb2(osiz4fxy, osiz4fxy, sgdub, wkmm, ldk-1, nk*wy1vqfzu)
@@ -309,9 +309,9 @@ C23081 continue
       call wbvalue(ankcghz2, rpyis2kc(1,yq6lorbx), nk, ifour4, chw8lzty,
      * izero0, t8hwvalr(ayfnwr1v,yq6lorbx))
 23086 continue
-C23087 continue
+23087 continue
 23084 continue
-C23085 continue
+23085 continue
       return
       end
       subroutine vsuff9(kuzxj1lo,nef,ezlgm2up, he7mqnvy,tlgduey8,wmat, p
@@ -341,29 +341,29 @@ C23085 continue
       do23094 ayfnwr1v=1,kuzxj1lo 
       pygsw6ko(ezlgm2up(ayfnwr1v))=he7mqnvy(ayfnwr1v)
 23094 continue
-C23095 continue
+23095 continue
       do23096 yq6lorbx=1,wy1vqfzu 
       do23098 ayfnwr1v=1,nef 
       wpasjmo8g(ayfnwr1v,yq6lorbx) = 0.0d0
 23098 continue
-C23099 continue
+23099 continue
 23096 continue
-C23097 continue
+23097 continue
       do23100 yq6lorbx=1,dimw 
       do23102 ayfnwr1v=1,nef 
       wbar(ayfnwr1v,yq6lorbx) = 0.0d0
 23102 continue
-C23103 continue
+23103 continue
 23100 continue
-C23101 continue
+23101 continue
       if(dimw .ne. imk5wjxg)then
       do23106 gp1jxzuh=1,wy1vqfzu 
       do23108 yq6lorbx=1,wy1vqfzu 
       work(yq6lorbx,gp1jxzuh) = 0.0d0
 23108 continue
-C23109 continue
+23109 continue
 23106 continue
-C23107 continue
+23107 continue
       endif
       do23110 ayfnwr1v=1,kuzxj1lo 
       do23112 yq6lorbx=1,dimw 
@@ -372,23 +372,23 @@ C23107 continue
       work(dufozmt7(yq6lorbx),tgiyxdw1(yq6lorbx)) = work(tgiyxdw1(yq6lor
      *bx),dufozmt7(yq6lorbx))
 23112 continue
-C23113 continue
+23113 continue
       do23114 yq6lorbx=1,wy1vqfzu 
       do23116 gp1jxzuh=1,wy1vqfzu 
       wpasjmo8g(ezlgm2up(ayfnwr1v),yq6lorbx) = wpasjmo8g(ezlgm2up(ayfnwr
      *1v),yq6lorbx) + work(yq6lorbx,gp1jxzuh)*tlgduey8(ayfnwr1v,gp1jxzuh
      *)
 23116 continue
-C23117 continue
+23117 continue
 23114 continue
-C23115 continue
+23115 continue
       do23118 yq6lorbx=1,dimw 
       wbar(ezlgm2up(ayfnwr1v),yq6lorbx) = wbar(ezlgm2up(ayfnwr1v),yq6lor
      *bx) + wmat(ayfnwr1v,yq6lorbx)
 23118 continue
-C23119 continue
+23119 continue
 23110 continue
-C23111 continue
+23111 continue
       dvhw1ulq = 1
       if(iz2nbfjc .eq. 1)then
       do23122 ayfnwr1v=1,nef 
@@ -398,11 +398,11 @@ C23111 continue
       work(dufozmt7(yq6lorbx),tgiyxdw1(yq6lorbx)) = work(tgiyxdw1(yq6lor
      *bx),dufozmt7(yq6lorbx))
 23124 continue
-C23125 continue
+23125 continue
       do23126 yq6lorbx=1,wy1vqfzu 
       work(yq6lorbx,wy1vqfzu+1)=wpasjmo8g(ayfnwr1v,yq6lorbx)
 23126 continue
-C23127 continue
+23127 continue
       call vcholf(work, work(1,wy1vqfzu+1), wy1vqfzu, dvhw1ulq, oneint)
       if(dvhw1ulq .ne. 1)then
       return
@@ -412,23 +412,23 @@ C23127 continue
       uwbar(yq6lorbx,ayfnwr1v) = work(tgiyxdw1(yq6lorbx),dufozmt7(yq6lor
      *bx))
 23132 continue
-C23133 continue
+23133 continue
       endif
       do23134 yq6lorbx=1,wy1vqfzu 
       pasjmo8g(ayfnwr1v,yq6lorbx)=work(yq6lorbx,wy1vqfzu+1)
 23134 continue
-C23135 continue
+23135 continue
 23122 continue
-C23123 continue
+23123 continue
       else
       if(dimw .ne. imk5wjxg)then
       do23138 yq6lorbx=1,wy1vqfzu 
       do23140 gp1jxzuh=1,wy1vqfzu 
       work(yq6lorbx,gp1jxzuh) = 0.0d0
 23140 continue
-C23141 continue
+23141 continue
 23138 continue
-C23139 continue
+23139 continue
       endif
       do23142 ayfnwr1v=1,nef 
       call qpsedg8xf(tgiyxdw1, dufozmt7, wy1vqfzu)
@@ -438,11 +438,11 @@ C23139 continue
       work(dufozmt7(yq6lorbx),tgiyxdw1(yq6lorbx)) = work(tgiyxdw1(yq6lor
      *bx),dufozmt7(yq6lorbx))
 23144 continue
-C23145 continue
+23145 continue
       do23146 yq6lorbx=1,wy1vqfzu 
       work(yq6lorbx,wy1vqfzu+1)=wpasjmo8g(ayfnwr1v,yq6lorbx)
 23146 continue
-C23147 continue
+23147 continue
       do23148 yq6lorbx=1,kgwmz4ip 
       do23150 gp1jxzuh=yq6lorbx,kgwmz4ip 
       work2(yq6lorbx,gp1jxzuh) = 0.0d0
@@ -452,32 +452,32 @@ C23147 continue
      *hxe6t,yq6lorbx) * work(urohxe6t,bpvaqm5z) * hjm2ktyr(bpvaqm5z,gp1j
      *xzuh)
 23154 continue
-C23155 continue
+23155 continue
 23152 continue
-C23153 continue
+23153 continue
 23150 continue
-C23151 continue
+23151 continue
 23148 continue
-C23149 continue
+23149 continue
       call qpsedg8xf(tgiyxdw1, dufozmt7, kgwmz4ip)
       do23156 yq6lorbx=1,dimu 
       wbar(ayfnwr1v,yq6lorbx) = work2(tgiyxdw1(yq6lorbx),dufozmt7(yq6lor
      *bx))
 23156 continue
-C23157 continue
+23157 continue
       do23158 yq6lorbx=1,kgwmz4ip 
       work2(yq6lorbx,kgwmz4ip+1) = 0.0d0
       do23160 urohxe6t=1,wy1vqfzu 
       work2(yq6lorbx,kgwmz4ip+1) = work2(yq6lorbx,kgwmz4ip+1) + hjm2ktyr
      *(urohxe6t,yq6lorbx) * work(urohxe6t,wy1vqfzu+1)
 23160 continue
-C23161 continue
+23161 continue
 23158 continue
-C23159 continue
+23159 continue
       do23162 yq6lorbx=1,kgwmz4ip 
       wpasjmo8g(ayfnwr1v,yq6lorbx) = work2(yq6lorbx,kgwmz4ip+1)
 23162 continue
-C23163 continue
+23163 continue
       call vcholf(work2, work2(1,kgwmz4ip+1), kgwmz4ip, dvhw1ulq, oneint
      *)
       if(dvhw1ulq .ne. 1)then
@@ -488,14 +488,14 @@ C23163 continue
       uwbar(yq6lorbx,ayfnwr1v) = work2(tgiyxdw1(yq6lorbx),dufozmt7(yq6lo
      *rbx))
 23168 continue
-C23169 continue
+23169 continue
       endif
       do23170 yq6lorbx=1,kgwmz4ip 
       pasjmo8g(ayfnwr1v,yq6lorbx) = work2(yq6lorbx,kgwmz4ip+1)
 23170 continue
-C23171 continue
+23171 continue
 23142 continue
-C23143 continue
+23143 continue
       endif
       return
       end
@@ -517,9 +517,9 @@ C23143 continue
       do23176 ayfnwr1v=1,kuzxj1lo 
       grmuyvx9(ayfnwr1v,gp1jxzuh) = 0.0d0
 23176 continue
-C23177 continue
+23177 continue
 23174 continue
-C23175 continue
+23175 continue
       endif
       qaltf0nz = 0.10d-9
       call qpsedg8xf(tgiyxdw1, dufozmt7, wy1vqfzu)
@@ -528,9 +528,9 @@ C23175 continue
       do23182 gp1jxzuh=1,wy1vqfzu 
       bmb(yq6lorbx,gp1jxzuh)=0.0d0
 23182 continue
-C23183 continue
+23183 continue
 23180 continue
-C23181 continue
+23181 continue
       call vinterv(gkdx5jal(1), (nk+1), he7mqnvy(ayfnwr1v), dqlr5bse, pq
      *zfxw4i)
       if(pqzfxw4i.eq. 1)then
@@ -548,26 +548,26 @@ C23181 continue
       call o0xlszqr(wy1vqfzu, g9fvdrbw(urohxe6t-yq6lorbx+1,1) * g9fvdrbw
      *(urohxe6t-yq6lorbx+1,1), work, bmb)
 23188 continue
-C23189 continue
+23189 continue
       do23190 urohxe6t=yq6lorbx,yq6lorbx+3 
       do23192 bpvaqm5z=urohxe6t+1,yq6lorbx+3 
       call vsel(urohxe6t, bpvaqm5z, wy1vqfzu, nk, ldk, enaqpzk9, work)
       call o0xlszqr(wy1vqfzu, 2.0d0 * g9fvdrbw(urohxe6t-yq6lorbx+1,1) * 
      *g9fvdrbw(bpvaqm5z-yq6lorbx+1,1), work, bmb)
 23192 continue
-C23193 continue
+23193 continue
 23190 continue
-C23191 continue
+23191 continue
       if(jzwsy6tp .ne. 0)then
       do23196 yq6lorbx=1,wy1vqfzu 
       grmuyvx9(ayfnwr1v,yq6lorbx) = bmb(yq6lorbx,yq6lorbx)
 23196 continue
-C23197 continue
+23197 continue
       endif
       call ovjnsmt2(bmb, wmat, work, ifys6woa, wy1vqfzu, kuzxj1lo, dimw,
      * tgiyxdw1, dufozmt7, ayfnwr1v)
 23178 continue
-C23179 continue
+23179 continue
       return
       end
       subroutine o0xlszqr(wy1vqfzu, g9fvdrbw, work, bmb)
@@ -580,17 +580,17 @@ C23179 continue
       do23200 gp1jxzuh=1,wy1vqfzu 
       work(yq6lorbx,gp1jxzuh) = work(yq6lorbx,gp1jxzuh) * g9fvdrbw
 23200 continue
-C23201 continue
+23201 continue
 23198 continue
-C23199 continue
+23199 continue
       do23202 yq6lorbx=1,wy1vqfzu 
       do23204 gp1jxzuh=1,wy1vqfzu 
       bmb(gp1jxzuh,yq6lorbx) = bmb(gp1jxzuh,yq6lorbx) + work(gp1jxzuh,yq
      *6lorbx)
 23204 continue
-C23205 continue
+23205 continue
 23202 continue
-C23203 continue
+23203 continue
       return
       end
       subroutine vsel(s, t, wy1vqfzu, nk, ldk, minv, work)
@@ -602,9 +602,9 @@ C23203 continue
       do23208 yq6lorbx=1,wy1vqfzu 
       work(ayfnwr1v,yq6lorbx) = 0.0d0
 23208 continue
-C23209 continue
+23209 continue
 23206 continue
-C23207 continue
+23207 continue
       if(s .ne. t)then
       do23212 ayfnwr1v=1,wy1vqfzu 
       biuvowq2 = (s-1)*wy1vqfzu + ayfnwr1v
@@ -612,9 +612,9 @@ C23207 continue
       nbj8tdsk = (t-1)*wy1vqfzu + yq6lorbx
       work(ayfnwr1v,yq6lorbx) = minv(ldk-(nbj8tdsk-biuvowq2), nbj8tdsk)
 23214 continue
-C23215 continue
+23215 continue
 23212 continue
-C23213 continue
+23213 continue
       else
       do23216 ayfnwr1v=1,wy1vqfzu 
       biuvowq2 = (s-1)*wy1vqfzu + ayfnwr1v
@@ -622,16 +622,16 @@ C23213 continue
       nbj8tdsk = (t-1)*wy1vqfzu + yq6lorbx
       work(ayfnwr1v,yq6lorbx) = minv(ldk-(nbj8tdsk-biuvowq2), nbj8tdsk)
 23218 continue
-C23219 continue
+23219 continue
 23216 continue
-C23217 continue
+23217 continue
       do23220 ayfnwr1v=1,wy1vqfzu 
       do23222 yq6lorbx=ayfnwr1v+1,wy1vqfzu 
       work(yq6lorbx,ayfnwr1v) = work(ayfnwr1v,yq6lorbx)
 23222 continue
-C23223 continue
+23223 continue
 23220 continue
-C23221 continue
+23221 continue
       endif
       return
       end
@@ -648,24 +648,24 @@ C23221 continue
       do23228 gp1jxzuh=1,wy1vqfzu 
       work(gp1jxzuh,yq6lorbx) = 0.0d0
 23228 continue
-C23229 continue
+23229 continue
 23226 continue
-C23227 continue
+23227 continue
       do23230 urohxe6t=1,dimw 
       obr6tcex = wmat(iii,urohxe6t)
       work(tgiyxdw1(urohxe6t),dufozmt7(urohxe6t)) = obr6tcex
       work(dufozmt7(urohxe6t),tgiyxdw1(urohxe6t)) = obr6tcex
 23230 continue
-C23231 continue
+23231 continue
       q6zdcwxk = 0.0d0
       do23232 yq6lorbx=1,wy1vqfzu 
       q6zdcwxk = q6zdcwxk + bmb(bpvaqm5z,yq6lorbx) * work(yq6lorbx,bpvaq
      *m5z)
 23232 continue
-C23233 continue
+23233 continue
       ifys6woa(iii,bpvaqm5z) = q6zdcwxk
 23224 continue
-C23225 continue
+23225 continue
       return
       end
       subroutine vicb2(enaqpzk9, wpuarq2m, d, uu, wy1vqfzu, kuzxj1lo)
@@ -682,9 +682,9 @@ C23225 continue
       do23236 ayfnwr1v=1,hofjnx2e 
       uu(ayfnwr1v, kij0gwer-sedf7mxb+1) = wpuarq2m(ayfnwr1v, kij0gwer)
 23236 continue
-C23237 continue
+23237 continue
 23234 continue
-C23235 continue
+23235 continue
       ayfnwr1v = kuzxj1lo-1 
 23238 if(.not.(ayfnwr1v .ge. 1))goto 23240
       if(wy1vqfzu .lt. kuzxj1lo-ayfnwr1v)then
@@ -701,7 +701,7 @@ C23235 continue
      *dbx3tk+wy1vqfzu+1,ayfnwr1v+lsvdbx3tk) - uu(-gp1jxzuh+wy1vqfzu+1,ay
      *fnwr1v+gp1jxzuh -sedf7mxb+1) * enaqpzk9(gp1jxzuh-lsvdbx3tk+wy1vqfz
      *u+1,ayfnwr1v+lsvdbx3tk)
-      gp1jxzuh=gp1jxzuh+1
+23247 gp1jxzuh=gp1jxzuh+1
       goto 23246
 23248 continue
 23249 if(.not.(gp1jxzuh .le. uplim))goto 23251
@@ -709,10 +709,10 @@ C23235 continue
      *dbx3tk+wy1vqfzu+1,ayfnwr1v+lsvdbx3tk) - uu(-gp1jxzuh+wy1vqfzu+1,ay
      *fnwr1v+gp1jxzuh -sedf7mxb+1) * enaqpzk9(lsvdbx3tk-gp1jxzuh+wy1vqfz
      *u+1,ayfnwr1v+gp1jxzuh)
-      gp1jxzuh=gp1jxzuh+1
+23250 gp1jxzuh=gp1jxzuh+1
       goto 23249
 23251 continue
-      lsvdbx3tk=lsvdbx3tk+1
+23244 lsvdbx3tk=lsvdbx3tk+1
       goto 23243
 23245 continue
       enaqpzk9(wy1vqfzu+1,ayfnwr1v) = 1.0d0 / d(ayfnwr1v)
@@ -721,7 +721,7 @@ C23235 continue
       enaqpzk9(wy1vqfzu+1,ayfnwr1v) = enaqpzk9(wy1vqfzu+1,ayfnwr1v) - uu
      *(-lsvdbx3tk+wy1vqfzu+1,ayfnwr1v+lsvdbx3tk -sedf7mxb+1) * enaqpzk9(
      *-lsvdbx3tk+wy1vqfzu+1,ayfnwr1v+lsvdbx3tk)
-      lsvdbx3tk=lsvdbx3tk+1
+23253 lsvdbx3tk=lsvdbx3tk+1
       goto 23252
 23254 continue
       if(ayfnwr1v .eq. sedf7mxb)then
@@ -734,21 +734,21 @@ C23235 continue
       gp1jxzuh=1
 23262 if(.not.(gp1jxzuh .le. hofjnx2e))goto 23264
       uu(gp1jxzuh,kij0gwer+1) = uu(gp1jxzuh,kij0gwer)
-      gp1jxzuh=gp1jxzuh+1
+23263 gp1jxzuh=gp1jxzuh+1
       goto 23262
 23264 continue
-      kij0gwer=kij0gwer-1
+23260 kij0gwer=kij0gwer-1
       goto 23259
 23261 continue
       gp1jxzuh=1
 23265 if(.not.(gp1jxzuh .le. hofjnx2e))goto 23267
       uu(gp1jxzuh,1) = wpuarq2m(gp1jxzuh,sedf7mxb)
-      gp1jxzuh=gp1jxzuh+1
+23266 gp1jxzuh=gp1jxzuh+1
       goto 23265
 23267 continue
       endif
       endif
-      ayfnwr1v = ayfnwr1v-1
+23239 ayfnwr1v = ayfnwr1v-1
       goto 23238
 23240 continue
       return
@@ -798,7 +798,7 @@ C23235 continue
       do23272 ayfnwr1v=1,nef 
       xin(ayfnwr1v) = (xin(ayfnwr1v)-xmin)/xrange
 23272 continue
-C23273 continue
+23273 continue
       ldk = 4*kgwmz4ip
       fbd5yktj = 0
       do23274 yq6lorbx=1,kgwmz4ip 
@@ -806,7 +806,7 @@ C23273 continue
       dof(yq6lorbx) = dof(yq6lorbx) + 1.0d0
       endif
 23274 continue
-C23275 continue
+23275 continue
       call qpsedg8xf(tgiyxdw1, dufozmt7, kgwmz4ip)
       call vsplin(xin,rbne6ouj,win,nef,zv2xfhei, acpios9q,ldk,kgwmz4ip,d
      *imwin, tgiyxdw1,dufozmt7, wkmm, wbkq9zyi, info, sout, rpyis2kc, wo
@@ -817,9 +817,9 @@ C23275 continue
       do23280 ayfnwr1v=1,nef 
       dof(yq6lorbx)=dof(yq6lorbx)+ifys6woa(ayfnwr1v,yq6lorbx)
 23280 continue
-C23281 continue
+23281 continue
 23278 continue
-C23279 continue
+23279 continue
       if(kgwmz4ip .ge. 1)then
       pvofyg8z = 1.0d-7
       rutyk8mg = nef*kgwmz4ip
@@ -833,7 +833,7 @@ C23279 continue
       do23284 gp1jxzuh=1,xjc4ywlh 
       ges1xpkr(gp1jxzuh) = gp1jxzuh
 23284 continue
-C23285 continue
+23285 continue
       call vqrdca(work3,rutyk8mg,rutyk8mg,xjc4ywlh,fasrkub3,ges1xpkr,wor
      *k1,qemj9asg,pvofyg8z)
       call qpsedg8xf(tgiyxdw1, dufozmt7, kgwmz4ip)
@@ -855,9 +855,9 @@ C23285 continue
      *orbx,1) - xin(ayfnwr1v) * (2.0d0 * s0(yq6lorbx,yq6lorbx+kgwmz4ip,1
      *) + xin(ayfnwr1v) * s0(yq6lorbx+kgwmz4ip,yq6lorbx+kgwmz4ip,1))
 23292 continue
-C23293 continue
+23293 continue
 23290 continue
-C23291 continue
+23291 continue
       endif
       else
       call dsrt0gem(nef, xin, win, sout, ub4xioar, cov, yzoe1rsp)
@@ -867,14 +867,14 @@ C23291 continue
       sout(ayfnwr1v,yq6lorbx) = sout(ayfnwr1v,yq6lorbx) - ub4xioar(yq6lo
      *rbx,ayfnwr1v)
 23296 continue
-C23297 continue
+23297 continue
 23294 continue
-C23295 continue
+23295 continue
       do23298 yq6lorbx=1,kgwmz4ip 
       call shm8ynte(kuzxj1lo, nef, ezlgm2up, sout(1,yq6lorbx), smo(1,yq6
      *lorbx))
 23298 continue
-C23299 continue
+23299 continue
       return
       end
       subroutine x6kanjdh(he7mqnvy, xout, kuzxj1lo, wy1vqfzu)
@@ -893,11 +893,11 @@ C23299 continue
       endif
       iptr=iptr+1
 23304 continue
-C23305 continue
+23305 continue
 23302 continue
-C23303 continue
+23303 continue
 23300 continue
-C23301 continue
+23301 continue
       do23308 yq6lorbx=1,wy1vqfzu 
       do23310 ayfnwr1v=1,kuzxj1lo 
       do23312 gp1jxzuh=1,wy1vqfzu 
@@ -908,11 +908,11 @@ C23301 continue
       endif
       iptr=iptr+1
 23312 continue
-C23313 continue
+23313 continue
 23310 continue
-C23311 continue
+23311 continue
 23308 continue
-C23309 continue
+23309 continue
       return
       end
       double precision function rd9beyfk(kuzxj1lo, bhcji9gl, m0ibglfx, p
@@ -929,7 +929,7 @@ C23309 continue
       rxeqjn0y = rxeqjn0y + po8rwsmy(ayfnwr1v)*work*work
       lm9vcjob = lm9vcjob + po8rwsmy(ayfnwr1v)
 23316 continue
-C23317 continue
+23317 continue
       if(lm9vcjob .gt. 0.0d0)then
       rd9beyfk=rxeqjn0y/lm9vcjob
       else
@@ -951,7 +951,7 @@ C23317 continue
       rxeqjn0y = rxeqjn0y + bhcji9gl(ayfnwr1v) * po8rwsmy(ayfnwr1v)
       lm9vcjob = lm9vcjob + po8rwsmy(ayfnwr1v)
 23320 continue
-C23321 continue
+23321 continue
       if(lm9vcjob .gt. 0.0d0)then
       lfu2qhid = rxeqjn0y / lm9vcjob
       else
@@ -981,13 +981,13 @@ C23321 continue
       hofjnx2e = hofjnx2e * hofjnx2e
       q6zdcwxk = q6zdcwxk + hofjnx2e * w(ayfnwr1v)
 23324 continue
-C23325 continue
+23325 continue
       eck8vubt = nsum/q6zdcwxk
       interc = pasjmo8g - eck8vubt * pygsw6ko
       do23326 ayfnwr1v=1,kuzxj1lo 
       ub4xioar(ayfnwr1v) = interc + eck8vubt * x(ayfnwr1v)
 23326 continue
-C23327 continue
+23327 continue
       bzmd6ftv = interc + eck8vubt * x(1)
       if(yzoe1rsp .ne. 0)then
       do23330 ayfnwr1v=1,kuzxj1lo 
@@ -999,7 +999,7 @@ C23327 continue
       cov(ayfnwr1v,1) = 0.0d0
       endif
 23330 continue
-C23331 continue
+23331 continue
       endif
       return
       end
@@ -1011,7 +1011,7 @@ C23331 continue
       do23334 ayfnwr1v=1,kuzxj1lo 
       x(ayfnwr1v) = pygsw6ko(ezlgm2up(ayfnwr1v))
 23334 continue
-C23335 continue
+23335 continue
       return
       end
       subroutine vankcghz2l2(x, kuzxj1lo, ankcghz2, rvy1fpli, ukgwt7na)
@@ -1032,15 +1032,15 @@ C23335 continue
       do23340 yq6lorbx = 1,3 
       ankcghz2(yq6lorbx) = x(1) 
 23340 continue
-C23341 continue
+23341 continue
       do23342 yq6lorbx = 1,ndk 
       ankcghz2(yq6lorbx+3) = x( 1 + (yq6lorbx-1)*(kuzxj1lo-1)/(ndk-1) ) 
 23342 continue
-C23343 continue
+23343 continue
       do23344 yq6lorbx = 1,3 
       ankcghz2(ndk+3+yq6lorbx) = x(kuzxj1lo) 
 23344 continue
-C23345 continue
+23345 continue
       return
       end
       subroutine pankcghz2l2(ankcghz2, kuzxj1lo, zo8wpibx, tol)
@@ -1051,7 +1051,7 @@ C23345 continue
       do23346 ayfnwr1v=1,4 
       zo8wpibx(ayfnwr1v) = 1
 23346 continue
-C23347 continue
+23347 continue
       cjop5bwm = 4
       do23348 ayfnwr1v=5,(kuzxj1lo-4) 
       if((ankcghz2(ayfnwr1v) - ankcghz2(cjop5bwm) .ge. tol) .and. (ankcg
@@ -1062,10 +1062,10 @@ C23347 continue
       zo8wpibx(ayfnwr1v) = 0
       endif
 23348 continue
-C23349 continue
+23349 continue
       do23352 ayfnwr1v=(kuzxj1lo-3),kuzxj1lo 
       zo8wpibx(ayfnwr1v) = 1
 23352 continue
-C23353 continue
+23353 continue
       return
       end
